==> haskell-cmark-gfm-0.2.6-70-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmark-gfm
version:              0.2.6
visibility:           public
id:                   cmark-gfm-0.2.6-1LyZLjkkd4b4UPY1EYknQV
key:                  cmark-gfm-0.2.6-1LyZLjkkd4b4UPY1EYknQV
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Asherah Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.13) and does not require prior installation of the
    C library.

category:             Text
abi:                  ad8641a348206111345cccde56cb6a1e
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cmark-gfm-0.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cmark-gfm-0.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cmark-gfm-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.6-1LyZLjkkd4b4UPY1EYknQV
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmark-gfm-0.2.6-71-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-cmark-gfm.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cmark-gfm
version:              0.2.6
visibility:           public
id:                   cmark-gfm-0.2.6-8YQsw5Mg46Q4oSpfakmwGu
key:                  cmark-gfm-0.2.6-8YQsw5Mg46Q4oSpfakmwGu
license:              BSD-3-Clause
copyright:            (C) 2015--17 John MacFarlane, (C) 2017--19 Ashe Connor
maintainer:           ashe@kivikakk.ee
author:               Asherah Connor
homepage:             https://github.com/kivikakk/cmark-gfm-hs
synopsis:             Fast, accurate GitHub Flavored Markdown parser and renderer
description:
    This package provides Haskell bindings for
    <https://github.com/github/cmark-gfm libcmark-gfm>, the reference
    parser for <https://github.github.com/gfm/ GitHub Flavored Markdown>, a fully
    specified variant of Markdown. It includes sources for
    libcmark-gfm (0.29.0.gfm.13) and does not require prior installation of the
    C library.

category:             Text
abi:                  dcdb22304d12b1732a64ff6320a1a4a5
exposed:              True
exposed-modules:      CMarkGFM
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cmark-gfm-0.2.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cmark-gfm-0.2.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cmark-gfm-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cmark-gfm
hs-libraries:         HScmark-gfm-0.2.6-8YQsw5Mg46Q4oSpfakmwGu
extra-libraries:      cmark-gfm cmark-gfm-extensions
depends:              base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
haddock-interfaces:   /usr/share/doc/haskell-cmark-gfm/html/cmark-gfm.haddock
haddock-html:         /usr/share/doc/haskell-cmark-gfm/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
